@@ -1,6 +1,6 @@
 ;;; sb-ruby.el --- shimbun backend class for ruby ML archiver.
 
-;; Copyright (C) 2001 NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
+;; Copyright (C) 2001, 2002 NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Keywords: news
@@ -94,7 +94,7 @@
 		id url date subject from)
 	    (goto-char (point-min))
 	    (while (re-search-forward
-		    "^<DT><A NAME=\"[0-9]+\"><A HREF=\"\\([^>]+\\)\">\\([0-9]+\\)</A> \\([ /:0-9]+\\) \\[\\([^[]+\\)\\] \\(.+\\)$"
+		    "^<DT><A NAME=\"[0-9]+\"></A><A HREF=\"\\([^>]+\\)\">\\([0-9]+\\)</A> \\([ /:0-9]+\\) \\[\\([^[]+\\)\\] \\(.+\\)$"
 		    nil t)
 	      (setq url (concat shimbun-ruby-url (match-string 1))
 		    id (format "<%s%05d%%%s>"
@@ -117,7 +117,7 @@
 
 (luna-define-method shimbun-make-contents ((shimbun shimbun-ruby) header)
   (let ((headers '(("^Subject: \\(.+\\)$" . shimbun-header-set-subject)
-		   ("^From :\\(.+\\)$" . shimbun-header-set-from)
+		   ("^From:\\(.+\\)$" . shimbun-header-set-from)
 		   ("^Date: \\(.+\\)$" . shimbun-header-set-date)))
 	;; any other headers to be included?
 	;;<A NAME=head></A><pre><A HREF="/cgi-bin/scat.rb/ruby/ruby-list/29726">...<a href="/ruby/ruby-list/29727">o</a> <a href="/cgi-bin/scat.rb/ruby/ruby-list/29727?help">HELP</a>
