@@ -1,6 +1,6 @@
 ;;; w3mhack.el --- a hack to setup the environment for building w3m
 
-;; Copyright (C) 2001 TSUCHIYA Masatoshi <tsuchiya@namazu.org>
+;; Copyright (C) 2001,2002 TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 
 ;; Author: Katsumi Yamaoka <yamaoka@jpl.org>
 ;; Keywords: w3m, WWW, hypermedia
@@ -77,6 +77,7 @@
     (unless (locate-library "mew")
       (push "mew-w3m.el" ignores))
     (unless (and (boundp 'emacs-major-version)
+		 (featurep 'mule)
 		 (if (featurep 'xemacs)
 		     ;; Mule-UCS does not support XEmacs versions prior
 		     ;; to 21.2.37.
@@ -87,9 +88,10 @@
 		   (>= emacs-major-version 20))
 		 (locate-library "un-define"))
       (push "w3m-ucs.el" ignores))
-    (if (locate-library "mime-def")
-	;; Add shimbun modules.
+    (if (and (featurep 'mule)
+	     (locate-library "mime-def"))
 	(progn
+	  ;; Add shimbun modules.
 	  (dolist (file (directory-files (expand-file-name shimbun-dir)
 					 nil "^[^#]+\\.el$"))
 	    (setq modules (nconc modules (list (concat shimbun-dir file)))))
@@ -404,7 +406,7 @@ run-time.  The file name is specified by `w3mhack-colon-keywords-file'."
 	     :require :set :tag :type))
 	  ;; Add el(c) files in the following list if necessary.
 	  ;; Each file should be representative file of a package
-	  ;; which will be used together with Emacs-W3M.
+	  ;; which will be used together with emacs-w3m.
 	  (setq files (list (locate-library "mailcap")
 			    (locate-library "mime-def")
 			    (locate-library "path-util")
@@ -486,7 +488,7 @@ run-time.  The file name is specified by `w3mhack-colon-keywords-file'."
 	  (insert ";;; " w3mhack-colon-keywords-file "\
  --- List of colon keywords which will be bound at run-time
 
-;; This file should be generated by make in Emacs-W3M source directory.
+;; This file should be generated by make in emacs-w3m source directory.
 ;; There are some colon keywords which were found in the directories
 ;; listed below:
 ;;
